use " rndhrs_i.dta" , clear

**Keep HRS Cohort**
tab racohbyr
keep if  racohbyr == 3

foreach var in mstat gender hosp hsptim oopmd agey_b educ hlthlm shlt bmi dress liv75 higov hiothp covr covs hltc hibp diab cancr lung heart strok psych arthr conde {
rename s1`var' s`var'1
rename s2`var' s`var'2
rename s3`var' s`var'3
rename s4`var' s`var'4
rename s5`var' s`var'5
rename s6`var' s`var'6
rename s7`var' s`var'7
rename s8`var' s`var'8
}
foreach var in mstat hosp hsptim oopmd agey_b hlthlm shlt bmi dress liv75 higov hiothp covr covs hltc hibp diab cancr lung heart strok psych arthr conde {

rename r1`var' r`var'1
rename r2`var' r`var'2
rename r3`var' r`var'3
rename r4`var' r`var'4
rename r5`var' r`var'5
rename r6`var' r`var'6
rename r7`var' r`var'7
rename r8`var' r`var'8
}
rename r2shltc rshltc2
rename r3shltc rshltc3
rename r4shltc rshltc4
rename r5shltc rshltc5
rename r6shltc rshltc6
rename r7shltc rshltc7
rename r8shltc rshltc8

rename r2liv10 rliv102
rename r3liv10 rliv103
rename r5liv10 rliv105
rename r6liv10 rliv106
rename r7liv10 rliv107
rename r8liv10 rliv108

rename ragender rgender1
rename raeduc reduc1
rename radiget radiget1 

**Keeping relevant variables**
keep hhidpn *mstat* *bmonth* *byear* *bdate* *cohbyr* *gender* *hosp* *hsptim* *higov* *hiothp* *covr* *covs* *oopmd* *agey_b* *educ* *hlthlm* *shlt* *bmi* *dress* *liv75* *liv10* *conde* *higov* *hiothp* *shltc* radiget* *hibp* *diab* *cancr* *lung* *heart* *strok* *psych* *arthr*

**Reshape data long**
reshape long rmstat rgender rhosp rhsptim roopmd ragey_b reduc rhlthlm rshlt rbmi rdress rliv75 rliv10 rhigov rhiothp rcovr rcovs rshltc rhibp rdiab rcancr rlung rheart rstrok rpsych rarthr rconde radiget, i(hhidpn) j(wave)

***Keep - main respondents***
keep  hhidpn  r* wave

**Keeping individuals there for 3 or more years***
sort hhidpn 
egen _3obs = count(ragey_b), by(hhidpn)
keep if _3obs >=3

**Individual age
gen rage = .
replace rage = ragey_b if ragey_b != .

***Education** 
sort hhidpn 
egen educ = mean(reduc), by(hhidpn)
replace reduc = educ if ragey_b != . 

**Gender**
sort hhidpn 
egen gender = mean(rgender), by(hhidpn)
replace rgender = gender if ragey_b != . 
drop gender educ

***Female***
gen female = .
replace female = 0 if rgender == 1
replace female = 1 if rgender == 2

**GED plus***
gen gedplus = .
replace gedplus = 0 if reduc == 1
replace gedplus = 1 if reduc != 1 & reduc != .

***Difficulty Dressing**
rename rdress rdress1
gen rdress = .
replace rdress = 1 if rdress1 == 0
replace rdress = 0 if rdress1 > 0 & rdress1!=.

**Do health problems limit work**
gen rwork = .
replace rwork = 0 if rhlthlm == 0
replace rwork = 1 if rhlthlm == 1

**Expected life length**
tab rliv75
gen rliv = rliv75
replace rliv = . if rliv < 0 | rliv >100
replace rliv =  rliv10 if rliv == . & rliv10 ! = .
replace rliv = . if rliv < 0 | rliv >100

**Health***
**Health - SA Health***
gen rshlth = .
replace rshlth  = -2 if rshlt == 1
replace rshlth  = -1 if rshlt == 2
replace rshlth  = -0 if rshlt == 3
replace rshlth  = 1 if rshlt == 4
replace rshlth  = 2 if rshlt == 5

**Health Changes***
gen rshlthc = .
replace rshlthc = rshltc
replace rshltc = . if rshltc == .p

*Set health changes 0 in first wave**
replace rshltc = 0 if rshltc == . & wave == 1
replace rshlthc = 0 if rshlthc == . & wave == 1

***BMI***
replace rbmi = . if rbmi == .m

*****Insurance coverage***
**rhigov - Governement Program, rcovr - covered by r insurance, rcovr - covered by Spouses insurance policy, rhiothp - Covered by other Policy**

**No spouse coverage if no spouse**
replace rcovs = 0 if rcovs == .  

gen insured = .
replace insured = 0 if  rhigov == 0 & rhiothp == 0 & rcovr == 0 & rcovs == 0 
replace  insured = 1 if rhigov == 1 | rhiothp == 1 |  rcovr == 1 | rcovs == 1

tab insured 
sort hhidpn
egen m_insured = mean(insured) if rage < 65, by(hhidpn)

gen covered1 = .
replace covered1 = 0 if m_insured <0.95
replace covered1 = 1 if m_insured >= 0.95 & m_insured <.

gen mostlycovered1= .
replace mostlycovered1 = 0 if m_insured<0.6 | m_insured >=0.95 & m_insured != .
replace mostlycovered1 = 1 if m_insured >= 0.6 & m_insured <0.95 

gen partlycovered1 = .
replace partlycovered1 = 0 if m_insured<0.1 | m_insured >=0.6 & m_insured != .
replace partlycovered1 = 1 if m_insured >= 0.1 & m_insured <0.6

sort hhidpn
egen covered = mean(covered1), by(hhidpn) 

sort hhidpn
egen mostlycovered = mean(mostlycovered1), by(hhidpn) 

sort hhidpn
egen partlycovered = mean(partlycovered1), by(hhidpn) 

replace rhigov = . if rage == .
replace rhigov = 0 if rhigov == . & rage!= . 
replace rhigov   = 0 if rhigov  != . & rhigov  != 0 & rhigov   != 1 & rage!= .  

replace rhiothp  = . if rage == .
replace rhiothp  = 0 if rhiothp  == . & rage!= .
replace rhiothp   = 0 if rhiothp  != . & rhiothp  != 0 & rhiothp   != 1 & rage!= .  

replace rcovr   = . if rage == .
replace rcovr   = 0 if rcovr   == . & rage!= . 
replace rcovr   = 0 if rcovr   != . & rcovr   != 0 & rcovr   != 1 & rage!= .  

replace rcovs   = . if rage == .
replace rcovs   = 0 if rcovs   == . & rage!= .  
replace rcovs   = 0 if rcovs   != . & rcovs   != 0 & rcovs   != 1 & rage!= .  

*Replace average variables missing if not observed**
replace covered = . if rage == .
replace mostlycovered = . if rage == .
replace partlycovered = . if rage == .

rename insured rinsured
replace rinsured   = . if rage == .
replace rinsured   = 0 if rinsured   == . & rage!= . 

**Any disability
**Currently have Chronic Disease
rename rhibp hibp1
rename rdiab diab1 
rename rcancr cancr1 
rename rlung lung1 
rename rheart heart1 
rename rstrok strok1
rename rpsych psych1
rename rarthr arthr1

gen rhibp = 0
replace rhibp = 0 if hibp1 == 0 | hibp1 == 4
replace rhibp = 1 if hibp1 == 1 | hibp1 == 3

gen rdiab = .
replace rdiab = 0 if diab1 == 0 | diab1 == 4
replace rdiab = 1 if diab1 ==1 | diab1 == 3

gen rcancr = .
replace rcancr = 0 if cancr1 == 0 | cancr1 == 4
replace rcancr = 1 if cancr1 == 1 | cancr1 == 3

gen rlung = .
replace rlung = 0 if lung1 == 0 | lung1 == 4
replace rlung = 1 if lung1 == 1 | lung1 == 3

gen rheart = .
replace rheart = 0 if heart1  == 0 | heart1  == 4
replace rheart = 1 if heart1  == 1 | heart1  == 3

gen rstrok = .
replace rstrok = 0 if strok1  == 0 | strok1  == 4
replace rstrok = 1 if strok1  == 1 | strok1  == 4

gen rpsych = .
replace rpsych = 0 if psych1  == 0 | psych1  == 4
replace rpsych = 1 if psych1  == 1 | psych1  == 3

gen rarthr = .
replace rarthr = 0 if arthr1  == 0 | arthr1  == 4
replace rarthr = 1 if arthr1 == 1 | arthr1  == 3

***Number of current chronic***
gen n_chronic = rhibp + rdiab +  rcancr + rlung + rheart + rstrok + rpsych + rarthr

**Number of conditions ever had***
gen n_cond = rconde

**Dummy for if ever had chronic disease**
gen rchronic = .
replace rchronic  = 0 if n_cond == 0
replace rchronic  = 1 if n_cond > 0 & n_cond != .

*Ever recieved Disability support****
sort hhidpn
egen anydisability = mean(radiget), by(hhidpn) 
replace anydisability = . if rage == .

***Dependent Variables***
tab rhsptim, missing 
replace rhsptim = . if rhsptim == .m
gen zerohosp = 1 if rhsptim == 0
replace zerohosp  = 0 if rhsptim  > 0 & rhsptim != .
* 0 for no dropout 
* 1 for intermittent missing
* 2 for permanent dropout

**No Drop out  observed for full 8 waves***
sort hhidpn
egen no_dropout1 = count(rage), by(hhidpn)
gen no_dropout = 1 if no_dropout1 == 8
replace no_dropout = 0 if no_dropout1 < 8 

*State dummy - 1 if in panel - zero otherwise***
gen state = .
replace state = 1 if rage>=0 & rage<.
replace state = 0 if rage == .

**First/last observation**
by hhidpn, sort: egen firsttime = min(cond(state == 1, wave, .))
by hhidpn: egen lasttime = max(cond(state == 1, wave, .))

**difference between first and last***

gen diff_last_first = lasttime - firsttime

**If difference = Nobs-1 and age in wave8 = ., then perm drop out.
**If difference != Nobs-1 Intermittent dropouts........"

gen nobs = no_dropout1
gen nobs_1 = nobs-1

***If they are observed on final wave
gen state8 = .
replace state8 = 0 if state != 1 & wave == 8
replace state8 = 1 if state == 1 & wave == 8

*R - index of Intermittentness**
**If number of obs = difference in 1st and last wave* 
gen obs_diff = diff_last_first - nobs_1 

**Observerd in first wave**
keep if firsttime == 1

gen R = .
replace R = 0 if nobs == 8
replace R = 0 if R== . & obs_diff == 0 & state8 == 1
replace R = 1 if R == . & obs_diff != . & obs_diff != 0 & state8 == 1   
replace R = 2 if R == . & state8 == 0 

sort hhidpn
egen r = mean(R), by(hhidpn)

drop R
rename r R

gen obs = .
replace obs = 0 if rage!= .
replace obs = 1 if R == 1 & rage == .
replace obs = 2 if R == 2 & rage == . 
replace obs = 1 if obs == 2 & wave < lasttime

rename R R_obs 
rename obs R 

**Keep relevant variables
keep hhidpn wave rhsptim nobs zerohosp roopmd rbmi rhigov rhiothp rinsured rcovr rcovs  covered mostlycovered partlycovered rhibp rdiab rshlthc rcancr rlung rheart rstrok rpsych rarthr rchronic n_cond anydisability zerohosp R  rshlt rshltc female gedplus rdress rwork rliv rage rshlth

**All waves observed have full data*
gen Drop = .
replace Drop = 0 if hhidpn != . & wave != . & rshlt != . &  rbmi != . &  rhsptim != . & roopmd != . & female != . & gedplus != . & rdress != . & rwork != . & rliv != . & rage != . & rshlth != . & covered != . & mostlycovered != . & partlycovered != . & rhibp != . & rdiab != . & rcancr != . & rlung != . & rheart != . & rstrok != . & rpsych != . & rarthr != . & n_cond != . & rchronic != . & anydisability != . & zerohosp != . & nobs != . & R != . 

sort hhidpn
egen C_Drop = count(Drop), by(hhidpn)

gen A = nobs - C_Drop 
tab A
keep if A == 0

drop A C_Drop Drop
drop rshltc

recast byte rshlt rcovr rcovs rhigov rhiothp

**Reshaping data wide**
reshape wide R nobs anydisability zerohosp rhibp rchronic n_cond rarthr rhigov rhiothp rinsured  rcovr rcovs rshlthc rpsych rstrok rheart rlung rcancr rdiab partlycovered mostlycovered covered rshlth rage rliv rwork rdress gedplus female roopmd rhsptim rbmi rshlt, i(hhidpn) j(wave)

*Sample of 500 individuals*
set seed 1234
sample 500, count

**reshape data long**
reshape long R nobs anydisability zerohosp rchronic n_cond rhigov rhiothp rinsured  rcovr rcovs rarthr rshlthc rpsych  rhibp rstrok rheart rlung rcancr rdiab partlycovered mostlycovered covered rshlth rage rliv rwork rdress gedplus female roopmd rhsptim rbmi rshlt, i(hhidpn) j(wave)
